@@ -53,7 +53,7 @@ def _init_pipeline(configs: _SPYDY_CONFIGS, pipeline: list):
             else:
                 pipeline.append(step_class())
     if isinstance(configs, dict):
-        pipeline = configs["PipeLine"]
+        pipeline.extend(configs["PipeLine"])
 
 
 def _init_statsReport(pipeline):
@@ -82,9 +82,15 @@ def handle_erroneous_exceptions(
     Handle exceptions while running through the pipeline
     """
     if verbose_flag == True:
-        print("{} was encountered, details: {}".format(type(exception), exception.args))
+        if exception:
+            print(
+                "{} was encountered, details: {}".format(
+                    type(exception), exception.args
+                )
+            )
 
-    excepitons_records[wrap_exceptions_message(exception)] += 1
+    if exception:
+        excepitons_records[wrap_exceptions_message(exception)] += 1
 
     handle_exceptions(
         temp_results=temp_results,
@@ -152,7 +158,7 @@ class Engine:
                         info_header="SUCCESS",
                         verbose=True,
                     )
-                else: 
+                else:
                     raise
 
     def run_once(self):
@@ -200,6 +206,16 @@ class Engine:
                         recovery_type="url_back_end",
                     )
                     temp_result = None
+                except:
+                    handle_erroneous_exceptions(
+                        exception=None,
+                        verbose_flag=self._verbose,
+                        excepitons_records=self._exceptions_records,
+                        temp_results=self._temp_results,
+                        pipeline=self._pipeline,
+                        recovery_type="url_back_end",
+                    )
+                    raise
                 self._temp_results[type(cur_step)] = temp_result
             final_result = temp_result
             return final_result
@@ -267,6 +283,16 @@ class Engine:
                         recovery_type="url_back_end",
                     )
                     temp_result = None
+                except:
+                    handle_erroneous_exceptions(
+                        exception=None,
+                        verbose_flag=self._verbose,
+                        excepitons_records=self._exceptions_records,
+                        temp_results=self._temp_results,
+                        pipeline=self._pipeline,
+                        recovery_type="url_back_end",
+                    )
+                    raise
                 self._temp_results[type(cur_step)] = temp_result
             final_result = temp_result
             return temp_result
