@@ -8,6 +8,7 @@ from requests.exceptions import (
     Timeout,
     ConnectTimeout,
     ReadTimeout,
+    ChunkedEncodingError,
 )
 
 _requests_request_exceptions = (
@@ -18,12 +19,10 @@ _requests_request_exceptions = (
     Timeout,
     ConnectTimeout,
     ReadTimeout,
+    ChunkedEncodingError,
 )
 
 
-##   Successful Exceptions
-
-
 class TaskDone(Exception):
     """
     Indicate that the tasks have be finished gracefully.
@@ -46,6 +45,16 @@ class UrlCompleted(TaskDone):
 
 
 ##   Different kinds of erroneous exceptions
+class TaskIgnore(Exception):
+    """
+    Ignore the task
+    """
+
+
+class TaskRunAgain(Exception):
+    """
+    Run the task again
+    """
 
 
 class TaskWrong(Exception):
@@ -66,12 +75,24 @@ class StepNotFound(Exception):
     """
 
 
-class UrlsStepNotFound(StepNotFound):
+class UrlsNotFound(StepNotFound):
     """
     Step of urls not found in pipeline
     """
 
 
+class StatsLogNotFound(StepNotFound):
+    """
+    Step of statslog not found in pipeline
+    """
+
+
+class ExceptionLogNotFound(StepNotFound):
+    """
+    Step of exceptionlog not found in pipeline
+    """
+
+
 class StepTypeNotSupported(Exception):
     """
     Step type is not stupported
@@ -87,4 +108,6 @@ class DummyUrlNotGiven(Exception):
 ## Put together
 
 Exceptions_To_Handle = (TaskWrong,) + _requests_request_exceptions
+Exceptions_To_Ignore = (TaskIgnore,)
+Exceptions_To_RunAgain = (TaskRunAgain,)
 Exceptions_Of_Success = (UrlCompleted,)
