@@ -17,6 +17,15 @@ class Request(Component):
         return self.request(*args, **kwargs)
 
 
+class AsyncRequest(AsyncComponent):
+    @abc.abstractmethod
+    def request(self):
+        ...
+
+    def __call__(self, *args, **kwargs):
+        return self.request(*args, **kwargs)
+
+
 def _prepare_proxies_for_requests(proxies):
     if callable(proxies):
         return proxies
@@ -40,7 +49,7 @@ class HttpRequest(Request):
         cookies=None,
         files=None,
         auth=None,
-        timeout=None,
+        timeout=10,
         allow_redirects=True,
         proxies=None,
         hooks=None,
@@ -78,7 +87,7 @@ class HttpRequest(Request):
                     cookies=run_if_callable(self._cookies),
                     files=run_if_callable(self._files),
                     auth=run_if_callable(self._auth),
-                    timeout=run_if_callable(self._timeout),
+                    timeout=float(run_if_callable(self._timeout)),
                     allow_redirects=run_if_callable(self._allow_redirects),
                     hooks=run_if_callable(self._hooks),
                     stream=run_if_callable(self._stream),
@@ -88,7 +97,7 @@ class HttpRequest(Request):
                 )
 
 
-class AsyncHttpRequest(Request, AsyncComponent):
+class AsyncHttpRequest(AsyncRequest):
     """
     Asynchronous http request, and its request method is a thin wrapper of requests.Request
     """
@@ -102,7 +111,7 @@ class AsyncHttpRequest(Request, AsyncComponent):
         cookies=None,
         files=None,
         auth=None,
-        timeout=None,
+        timeout=10,
         allow_redirects=True,
         proxies=None,
         hooks=None,
@@ -130,7 +139,6 @@ class AsyncHttpRequest(Request, AsyncComponent):
     async def request(self, url):
         if url:
             asession = AsyncHTMLSession()
-            # with AsyncHTMLSession() as asession:
             response = await asession.request(
                 self._method,
                 url,
@@ -141,7 +149,7 @@ class AsyncHttpRequest(Request, AsyncComponent):
                 cookies=run_if_callable(self._cookies),
                 files=run_if_callable(self._files),
                 auth=run_if_callable(self._auth),
-                timeout=run_if_callable(self._timeout),
+                timeout=float(run_if_callable(self._timeout)),
                 allow_redirects=run_if_callable(self._allow_redirects),
                 hooks=run_if_callable(self._hooks),
                 stream=run_if_callable(self._stream),
